@@ -865,6 +865,12 @@ module.exports = {
 	"85.0.4183.19": [
 		"10.0.0-beta.10"
 	],
+	"85.0.4183.20": [
+		"10.0.0-beta.11"
+	],
+	"85.0.4183.26": [
+		"10.0.0-beta.12"
+	],
 	"82.0.4050.0": [
 		"10.0.0-nightly.20200209",
 		"10.0.0-nightly.20200210",
@@ -954,5 +960,8 @@ module.exports = {
 		"11.0.0-nightly.20200707",
 		"11.0.0-nightly.20200708",
 		"11.0.0-nightly.20200709"
+	],
+	"86.0.4203.0": [
+		"11.0.0-nightly.20200716"
 	]
 };
\ No newline at end of file
