@@ -596,6 +596,8 @@ module.exports = {
 	"10.0.0-beta.8": "85.0.4181.1",
 	"10.0.0-beta.9": "85.0.4181.1",
 	"10.0.0-beta.10": "85.0.4183.19",
+	"10.0.0-beta.11": "85.0.4183.20",
+	"10.0.0-beta.12": "85.0.4183.26",
 	"10.0.0-nightly.20200209": "82.0.4050.0",
 	"10.0.0-nightly.20200210": "82.0.4050.0",
 	"10.0.0-nightly.20200211": "82.0.4050.0",
@@ -676,5 +678,6 @@ module.exports = {
 	"11.0.0-nightly.20200706": "85.0.4179.0",
 	"11.0.0-nightly.20200707": "85.0.4179.0",
 	"11.0.0-nightly.20200708": "85.0.4179.0",
-	"11.0.0-nightly.20200709": "85.0.4179.0"
+	"11.0.0-nightly.20200709": "85.0.4179.0",
+	"11.0.0-nightly.20200716": "86.0.4203.0"
 };
\ No newline at end of file
